# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class LabelProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'key': 'str',

        'resource_href': 'str',

        'resource_id': 'str',

        'resource_type': 'str',

        'value': 'str',
    }

    attribute_map = {

        'key': 'key',

        'resource_href': 'resourceHref',

        'resource_id': 'resourceId',

        'resource_type': 'resourceType',

        'value': 'value',
    }

    def __init__(self, key=None, resource_href=None, resource_id=None, resource_type=None, value=None, local_vars_configuration=None):  # noqa: E501
        """LabelProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._resource_href = None
        self._resource_id = None
        self._resource_type = None
        self._value = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if resource_href is not None:
            self.resource_href = resource_href
        if resource_id is not None:
            self.resource_id = resource_id
        if resource_type is not None:
            self.resource_type = resource_type
        if value is not None:
            self.value = value


    @property
    def key(self):
        """Gets the key of this LabelProperties.  # noqa: E501

        A label key  # noqa: E501

        :return: The key of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this LabelProperties.

        A label key  # noqa: E501

        :param key: The key of this LabelProperties.  # noqa: E501
        :type key: str
        """

        self._key = key

    @property
    def resource_href(self):
        """Gets the resource_href of this LabelProperties.  # noqa: E501

        URL to the Resource (absolute path) on which the label is applied.  # noqa: E501

        :return: The resource_href of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._resource_href

    @resource_href.setter
    def resource_href(self, resource_href):
        """Sets the resource_href of this LabelProperties.

        URL to the Resource (absolute path) on which the label is applied.  # noqa: E501

        :param resource_href: The resource_href of this LabelProperties.  # noqa: E501
        :type resource_href: str
        """

        self._resource_href = resource_href

    @property
    def resource_id(self):
        """Gets the resource_id of this LabelProperties.  # noqa: E501

        The ID of the resource.  # noqa: E501

        :return: The resource_id of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this LabelProperties.

        The ID of the resource.  # noqa: E501

        :param resource_id: The resource_id of this LabelProperties.  # noqa: E501
        :type resource_id: str
        """

        self._resource_id = resource_id

    @property
    def resource_type(self):
        """Gets the resource_type of this LabelProperties.  # noqa: E501

        The type of the resource on which the label is applied.  # noqa: E501

        :return: The resource_type of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this LabelProperties.

        The type of the resource on which the label is applied.  # noqa: E501

        :param resource_type: The resource_type of this LabelProperties.  # noqa: E501
        :type resource_type: str
        """

        self._resource_type = resource_type

    @property
    def value(self):
        """Gets the value of this LabelProperties.  # noqa: E501

        A label value  # noqa: E501

        :return: The value of this LabelProperties.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this LabelProperties.

        A label value  # noqa: E501

        :param value: The value of this LabelProperties.  # noqa: E501
        :type value: str
        """

        self._value = value
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LabelProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LabelProperties):
            return True

        return self.to_dict() != other.to_dict()
